@@ -63,6 +63,8 @@ static const char s_warnnotencrypt[] = "Warn not Encrypt";
 static const char s_defaultDomainName[] = "Default Domain";
 static const char s_autocryptEnabled[] = "Autocrypt";
 static const char s_autocryptPrefer[] = "Autocrypt Prefer";
+static const char s_activities[] = "Activities";
+static const char s_enabledActivities[] = "Enabled Activities";
 
 KIDENTITYMANAGEMENTCORE_EXPORT QDataStream &operator<<(QDataStream &stream, const KIdentityManagementCore::Identity &ident);
 KIDENTITYMANAGEMENTCORE_EXPORT QDataStream &operator>>(QDataStream &stream, KIdentityManagementCore::Identity &ident);
@@ -256,7 +258,7 @@ public:
      * @return The default language for spell checking of this identity.
      * @since 4.10
      */
-    QString autocorrectionLanguage() const;
+    [[nodiscard]] QString autocorrectionLanguage() const;
     void setAutocorrectionLanguage(const QString &language);
 
     /**
@@ -431,6 +433,12 @@ public:
      */
     void setUoid(uint aUoid);
 
+    [[nodiscard]] const QStringList activities() const;
+    void setActivities(const QStringList &a);
+
+    [[nodiscard]] bool enabledActivities() const;
+    void setEnabledActivities(bool a);
+
 protected:
     /** during migration when it failed it can be a string => not a qlonglong akonadi::id => fix it*/
     [[nodiscard]] QString verifyAkonadiId(const QString &str) const;
