@@ -14,13 +14,32 @@ IdentityTreeSortProxyModel::~IdentityTreeSortProxyModel() = default;
 
 bool IdentityTreeSortProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
-    if (mIdentityActivitiesAbstract) {
-        const auto activities = sourceModel()->index(source_row, 0).data(IdentityTreeModel::ActivitiesRole).toStringList();
-        return mIdentityActivitiesAbstract->filterAcceptsRow(activities);
+    if (mIdentityActivitiesAbstract && mEnablePlasmaActivities) {
+        const bool enableActivities = sourceModel()->index(source_row, IdentityTreeModel::EnabledActivitiesRole).data().toBool();
+        if (enableActivities) {
+            const auto activities = sourceModel()->index(source_row, IdentityTreeModel::ActivitiesRole).data().toStringList();
+            const bool result = mIdentityActivitiesAbstract->filterAcceptsRow(activities);
+            // qDebug() << " result " << result << " identity name : " << sourceModel()->index(source_row,
+            // IdentityTreeModel::IdentityNameRole).data().toString();
+            return result;
+        }
     }
     return QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent);
 }
 
+bool IdentityTreeSortProxyModel::enablePlasmaActivities() const
+{
+    return mEnablePlasmaActivities;
+}
+
+void IdentityTreeSortProxyModel::setEnablePlasmaActivities(bool newEnablePlasmaActivities)
+{
+    if (mEnablePlasmaActivities != newEnablePlasmaActivities) {
+        mEnablePlasmaActivities = newEnablePlasmaActivities;
+        invalidateFilter();
+    }
+}
+
 IdentityActivitiesAbstract *IdentityTreeSortProxyModel::identityActivitiesAbstract() const
 {
     return mIdentityActivitiesAbstract;
