@@ -22,7 +22,10 @@ class KeyUseTypes
     Q_GADGET
 
 public:
-    enum class KeyUse { KeySigningUse, KeyEncryptionUse };
+    enum class KeyUse {
+        KeySigningUse,
+        KeyEncryptionUse
+    };
     Q_ENUM(KeyUse)
 };
 
@@ -33,8 +36,11 @@ public:
 class KIDENTITYMANAGEMENTQUICK_EXPORT KeyListModelInterface
 {
 public:
-    virtual ~KeyListModelInterface(){};
-    enum Roles { KeyIdentifierRole = Qt::UserRole + 1, KeyByteArrayRole };
+    virtual ~KeyListModelInterface() {};
+    enum Roles {
+        KeyIdentifierRole = Qt::UserRole + 1,
+        KeyByteArrayRole
+    };
 
     static QHash<int, QByteArray> roleNames()
     {
