@@ -14,19 +14,20 @@ IdentityTreeView::IdentityTreeView(QWidget *parent)
     , mIdentityProxyModel(new KIdentityManagementCore::IdentityTreeSortProxyModel(this))
 {
     setAlternatingRowColors(true);
-    setSelectionMode(SingleSelection);
+    setSelectionMode(ExtendedSelection);
     setContextMenuPolicy(Qt::CustomContextMenu);
     setSelectionBehavior(QAbstractItemView::SelectRows);
     setRootIsDecorated(false);
     setSortingEnabled(true);
     setAllColumnsShowFocus(true);
+    setEditTriggers(QAbstractItemView::EditKeyPressed);
     header()->setSectionsMovable(false);
     header()->setSectionResizeMode(QHeaderView::ResizeToContents);
 
-    auto model = new KIdentityManagementCore::IdentityTreeModel(KIdentityManagementCore::IdentityManager::self(), this);
-    model->setShowDefault(true);
+    mIdentityModel = new KIdentityManagementCore::IdentityTreeModel(KIdentityManagementCore::IdentityManager::self(), this);
+    mIdentityModel->setShowDefault(true);
 
-    mIdentityProxyModel->setSourceModel(model);
+    mIdentityProxyModel->setSourceModel(mIdentityModel);
     setModel(mIdentityProxyModel);
 
     setColumnHidden(KIdentityManagementCore::IdentityTreeModel::DefaultRole, true);
@@ -34,6 +35,7 @@ IdentityTreeView::IdentityTreeView(QWidget *parent)
     setColumnHidden(KIdentityManagementCore::IdentityTreeModel::EmailRole, true);
     setColumnHidden(KIdentityManagementCore::IdentityTreeModel::IdentityNameRole, true);
     setColumnHidden(KIdentityManagementCore::IdentityTreeModel::ActivitiesRole, true);
+    setColumnHidden(KIdentityManagementCore::IdentityTreeModel::EnabledActivitiesRole, true);
     setItemDelegateForColumn(KIdentityManagementCore::IdentityTreeModel::DisplayIdentityNameRole, new IdentityTreeDelegate(this));
 }
 
@@ -44,9 +46,34 @@ KIdentityManagementCore::IdentityActivitiesAbstract *IdentityTreeView::identityA
     return mIdentityProxyModel->identityActivitiesAbstract();
 }
 
+bool IdentityTreeView::enablePlasmaActivities() const
+{
+    return mIdentityProxyModel->enablePlasmaActivities();
+}
+
+void IdentityTreeView::setEnablePlasmaActivities(bool newEnablePlasmaActivities)
+{
+    mIdentityProxyModel->setEnablePlasmaActivities(newEnablePlasmaActivities);
+}
+
+KIdentityManagementCore::IdentityTreeSortProxyModel *IdentityTreeView::identityProxyModel() const
+{
+    return mIdentityProxyModel;
+}
+
 void IdentityTreeView::setIdentityActivitiesAbstract(KIdentityManagementCore::IdentityActivitiesAbstract *newIdentityActivitiesAbstract)
 {
     mIdentityProxyModel->setIdentityActivitiesAbstract(newIdentityActivitiesAbstract);
 }
 
+KIdentityManagementCore::Identity &IdentityTreeView::modifyIdentityForUoid(uint uoid)
+{
+    return mIdentityModel->identityManager()->modifyIdentityForUoid(uoid);
+}
+
+KIdentityManagementCore::IdentityTreeModel *IdentityTreeView::identityTreeModel() const
+{
+    return mIdentityModel;
+}
+
 #include "moc_identitytreeview.cpp"
