@@ -9,6 +9,8 @@ namespace KIdentityManagementCore
 {
 class IdentityTreeSortProxyModel;
 class IdentityActivitiesAbstract;
+class Identity;
+class IdentityTreeModel;
 }
 namespace KIdentityManagementWidgets
 {
@@ -22,7 +24,17 @@ public:
     void setIdentityActivitiesAbstract(KIdentityManagementCore::IdentityActivitiesAbstract *newIdentityActivitiesAbstract);
     [[nodiscard]] KIdentityManagementCore::IdentityActivitiesAbstract *identityActivitiesAbstract() const;
 
+    [[nodiscard]] bool enablePlasmaActivities() const;
+    void setEnablePlasmaActivities(bool newEnablePlasmaActivities);
+
+    [[nodiscard]] KIdentityManagementCore::IdentityTreeSortProxyModel *identityProxyModel() const;
+
+    KIdentityManagementCore::Identity &modifyIdentityForUoid(uint uoid);
+
+    [[nodiscard]] KIdentityManagementCore::IdentityTreeModel *identityTreeModel() const;
+
 private:
     KIdentityManagementCore::IdentityTreeSortProxyModel *const mIdentityProxyModel;
+    KIdentityManagementCore::IdentityTreeModel *mIdentityModel = nullptr;
 };
 }
